@@ -12,9 +12,11 @@
 #' @param id Name of column containing row IDs. By default, the first column is
 #'   assumed.
 #' @param day.impute Integer. Day of the month to be imputed if not available.
-#'   defaults to 1. If \code{day.impute = NA} then \code{NA} will be imputed for
+#'   defaults to 1. Maximum value of 31. If day.impute is greater than the
+#'   number of days for a given month, then the last day of that month will be
+#'   imputed. If \code{day.impute = NA}, then \code{NA} will be imputed for
 #'   the date instead and a warning will be raised. If \code{day.impute = NULL}
-#'   then instead of imputing the day of the month, the function will fail
+#'   then instead of imputing the day of the month, the function will fail.
 #' @param month.impute Integer. Month to be be imputed if not available.
 #'   Defaults to 7 (July). If \code{month.impute = NA} then \code{NA} will be
 #'   imputed for the date instead and a warning will be raised. If
@@ -29,6 +31,11 @@
 #'   which counts the number of days from 1900-01-01? In most programming
 #'   languages (including R), days are instead calculated from 1970-01-01
 #'   and this is the default for this function (\code{excel = FALSE})
+#' @param roman.numeral `r lifecycle::badge("experimental")` Logical. If TRUE,
+#'   months detected to have been given as Roman numerals will be converted.
+#'   Months are given in Roman numerals in some database systems and biological
+#'   records. Defaults to FALSE as this may occasionally interfere with months
+#'   in other formats.
 #' @return A \code{dataframe} or \code{tibble} object. Dependent on the type of
 #'   \code{df}. Selected columns are of type \code{Date} with the following
 #'   format \code{yyyy-mm-dd}
@@ -45,7 +52,8 @@ fix_date_df <- function(df,
                         month.impute = 7,
                         id = NULL,
                         format = "dmy",
-                        excel = FALSE) {
+                        excel = FALSE,
+                        roman.numeral = FALSE) {
   if (!is.data.frame(df)) {
     stop("df should be a dataframe object!")
   }
@@ -70,7 +78,8 @@ fix_date_df <- function(df,
             month.impute,
             subject = df[i, id],
             format = format,
-            excel = excel
+            excel = excel,
+            roman.numeral = roman.numeral
           )
         },
         error = function(cond) {
