@@ -12,6 +12,15 @@ String process_french(String date) {
   return date;
 }
 
+// [[Rcpp::export]]
+String process_russian(String date) {
+  date.replace_all("марта", "март");
+  date.replace_all("Марта", "Март");
+  date.replace_all("августа", "август");
+  date.replace_all("Августа", "Август");
+  return date;
+}
+
 // [[Rcpp::export]]
 void imputemonth(Nullable<String> monthImpute_) {
   if (monthImpute_.isNull()) {
@@ -27,32 +36,17 @@ void imputeday(Nullable<String> dayImpute_) {
 }
 
 
-// [[Rcpp::export]]
-String rm_ordinal_suffixes(String date_) {
-  std::string date(date_);
-  date = std::regex_replace(date, std::regex("(\\d)(st,)"), "$1");
-  date = std::regex_replace(date, std::regex("(\\d)(nd,)"), "$1" );
-  date = std::regex_replace(date, std::regex("(\\d)(rd,)"), "$1" );
-  date = std::regex_replace(date, std::regex("(\\d)(th,)"), "$1" );
-  date = std::regex_replace(date, std::regex("(\\d)(st)"), "$1");
-  date = std::regex_replace(date, std::regex("(\\d)(nd)"), "$1" );
-  date = std::regex_replace(date, std::regex("(\\d)(rd)"), "$1" );
-  date = std::regex_replace(date, std::regex("(\\d)(th)"), "$1" );
-  String date2(date);
-  return date2;
-}
-
 // [[Rcpp::export]]
 void checkday(Nullable<NumericVector> dayImpute) {
   if (!dayImpute.isNull()) {
     NumericVector dayImpute_(dayImpute); 
     if (!NumericVector::is_na(dayImpute_[0])) {
-      if (dayImpute_[0] < 1 || dayImpute_[0] > 28) {
-        stop(_("day.impute should be an integer between 1 and 28\n"));
+      if (dayImpute_[0] < 1 || dayImpute_[0] > 31) {
+        stop(_("day.impute should be an integer between 1 and 31\n"));
       }
       if (floor(dayImpute_[0]) != dayImpute_[0]) {
         stop(_("day.impute should be an integer\n"));
-        }
       }
     }
+  }
 }
