@@ -12,6 +12,8 @@ if (l10n_info()$MBCS) {
         "05. J\u00E4nner 2021" = "2021-01-05",
         "J\u00E4n 2003" = "2003-01-01",
         "enero 2005" = "2005-01-01",
+        "ener 2010" = "2010-01-01",
+        "ene 2000" = "2000-01-01",
         "Jan 2010" = "2010-01-01",
         "10 de janeiro de 2019" = "2019-01-10",
         "18 \u044f\u043d\u0432\u0430\u0440\u044c 2023" = "2023-01-18",
